==> TellTrack_v1.002.zip: Interface/AddOns/TellTrack/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_TELLTRACKHEADER		= "Tell Track";
BINDING_NAME_TELLTRACK				= "Tell Track Toggle";
BINDING_NAME_TELLTRACK1				= "Send tell to tell track slot number 1";
BINDING_NAME_TELLTRACK2				= "Send tell to tell track slot number 2";
BINDING_NAME_TELLTRACK3				= "Send tell to tell track slot number 3";
BINDING_NAME_TELLTRACK4				= "Send tell to tell track slot number 4";

TELLTRACK_CONFIG_HEADER				= "Tell Track";
TELLTRACK_CONFIG_HEADER_INFO		= "Contains settings for Tell Track,\nan AddOn which makes it easier for you to talk to several people simultaneously.\nClick the question-mark corner for more info.";

TELLTRACK_ENABLED					= "Enable Tell Track";
TELLTRACK_ENABLED_INFO				= "Enables Tell Track, displaying its window.";

TELLTRACK_CHAT_ENABLED				= "Tell Track enabled.\nClick TellTracks question-mark corner for more info.";
TELLTRACK_CHAT_DISABLED				= "Tell Track disabled.";

TELLTRACK_CHAT_COMMAND_ENABLE_INFO	= "Enables/disables Tell Track.";
TELLTRACK_QUESTION_MARK_TOOLTIP		= "Click here for more info."

TELLTRACK_CHAT_QUESTION_MARK_INFO	= "TellTrack (by sarf and Lash)\n\nLMB on Slot:Send Tell\nRMB on Slot:Erase Slot\nMWheel:Scroll slots one by one (max 20)\nLMB on Arrows:Scroll slots page by page (max 20)\nRMB on Arrows:Go to first or last slot respectively.";

TELLTRACK_WHISPER					= "Whisper";
TELLTRACK_WHO						= "Who";
TELLTRACK_GRPINV					= "Groupe Invite";
TELLTRACK_ADDFRIEND					= "Add to Friends";
TELLTRACK_DELETE					= "Delete"
TELLTRACK_CANCEL					= "Cancel";


TELLTRACK_CONFIG_TRANSNUI			= "Transparent TellTrack";
TELLTRACK_CONFIG_TRANSNUI_INFO		= "Allows you to make TellTrack transparent";

TELLTRACK_CONFIG_POPNUI				= "Autohide TellTrack";
TELLTRACK_CONFIG_POPNUI_INFO		= "Check this to make TellTrack only show when you move your mouse over it.";

==> TellTrack_v1.004.zip: Interface/AddOns/TellTrack/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_TELLTRACKHEADER		= "Tell Track";
BINDING_NAME_TELLTRACK				= "Tell Track Toggle";
BINDING_NAME_TELLTRACK1				= "Send tell to first visible TellTrack slot";
BINDING_NAME_TELLTRACK2				= "Send tell to second visible TellTrack slot";
BINDING_NAME_TELLTRACK3				= "Send tell to third visible TellTrack slot";
BINDING_NAME_TELLTRACK4				= "Send tell to fourth visible TellTrack slot";

TELLTRACK_CONFIG_HEADER				= "Tell Track";
TELLTRACK_CONFIG_HEADER_INFO		= "Contains settings for Tell Track,\nan AddOn which makes it easier for you to talk to several people simultaneously.\nClick the question-mark corner for more info.";

TELLTRACK_ENABLED					= "Enable Tell Track";
TELLTRACK_ENABLED_INFO				= "Enables Tell Track, displaying its window.";

TELLTRACK_CHAT_ENABLED				= "Tell Track enabled.\nClick TellTracks question-mark corner for more info.";
TELLTRACK_CHAT_DISABLED				= "Tell Track disabled.";

TELLTRACK_CHAT_COMMAND_ENABLE_INFO	= "Enables/disables Tell Track.\nAlso, use /telltrack clearall to clear all entries.";
TELLTRACK_QUESTION_MARK_TOOLTIP		= "Click here for more info."

TELLTRACK_CHAT_QUESTION_MARK_INFO	= "TellTrack (by sarf and Lash)\n\nLMB on Slot:Send Tell\nRMB on Slot:Erase Slot\nMWheel:Scroll slots one by one (max 20)\nLMB on Arrows:Scroll slots page by page (max 20)\nRMB on Arrows:Go to first or last slot respectively.";

TELLTRACK_WHISPER					= "Whisper";
TELLTRACK_WHO						= "Who";
TELLTRACK_GRPINV					= "Groupe Invite";
TELLTRACK_ADDFRIEND					= "Add to Friends";
TELLTRACK_DELETE					= "Delete"
TELLTRACK_DELETE_ALL				= "Delete All"
TELLTRACK_CANCEL					= "Cancel";


TELLTRACK_CONFIG_TRANSNUI			= "Transparent TellTrack";
TELLTRACK_CONFIG_TRANSNUI_INFO		= "Allows you to make TellTrack transparent";

TELLTRACK_CONFIG_POPNUI				= "Autohide TellTrack";
TELLTRACK_CONFIG_POPNUI_INFO		= "Check this to make TellTrack only show when you move your mouse over it.";
